@@ -18,7 +18,6 @@ import sys
 import sh
 from string import Template
 from ferry.install import FERRY_HOME
-from ferry.docker.fabric import DockerFabric
 from ferry.config.hadoop.hiveconfig import *
 from ferry.config.system.info import *
 
@@ -63,22 +62,29 @@ class HadoopClientInitializer(object):
     def stop_service(self, containers, entry_point, fabric):        
         return self._execute_service(containers, entry_point, fabric, "stop")
 
-    """
-    Generate a new configuration.
-    """
     def _generate_config_dir(self, uuid):
+        """
+        Generate a new configuration.
+        """
         return 'hadoop_client_' + str(uuid)
 
-    """
-    Get the ports necessary. 
-    """
-    def get_necessary_ports(self, num_instances):
+    def get_public_ports(self, num_instances):
+        """
+        Ports to expose to the outside world. 
+        """
         return []
 
-    """
-    Get the internal ports. 
-    """
-    def get_exposed_ports(self, num_instances):
+    def get_internal_ports(self, num_instances):
+        """
+        Ports needed for communication within the network. 
+        This is usually used for internal IPC.
+        """
+        return []
+
+    def get_working_ports(self, num_instances):
+        """
+        Ports necessary to get things working. 
+        """
         return []
 
     """
@@ -196,7 +202,7 @@ class HadoopClientInitializer(object):
     """
     def apply(self, config, containers):
         entry_point = { 'type' : 'hadoop-client' }
-        entry_point['ip'] = containers[0]['data_ip']
+        entry_point['ip'] = containers[0]['manage_ip']
 
         # Create a new configuration directory, and place
         # into the template directory. 
