@@ -51,11 +51,24 @@ class OpenMPIClientInitializer(object):
     def stop_service(self, containers, entry_point, fabric):        
         return self.mpi.stop_service(containers, entry_point, fabric)
 
-    def get_necessary_ports(self, num_instances):
-        return self.mpi.get_necessary_ports(num_instances)
+    def get_public_ports(self, num_instances):
+        """
+        Ports to expose to the outside world. 
+        """
+        return []
 
-    def get_exposed_ports(self, num_instances):
-        return self.mpi.get_exposed_ports(num_instances)
+    def get_internal_ports(self, num_instances):
+        """
+        Ports needed for communication within the network. 
+        This is usually used for internal IPC.
+        """
+        return self.mpi.get_internal_ports(num_instances)
+
+    def get_working_ports(self, num_instances):
+        """
+        Ports necessary to get things working. 
+        """
+        return self.mpi.get_working_ports(num_instances)
 
     def generate(self, num):
         return self.mpi.generate(num)
